#!/usr/bin/env bash
#
# Copyright (c) 2023-2024 VMware Carbon Black, all rights reserved
#

_dbg=0
while getopts "d" options; do
    case "${options}" in
        d) _dbg=1;;
    esac
done

# handle -d (debugging) flag
if [[ ${_dbg} -eq 1 ]]; then
    set -x
fi

# Wait for last contact time updater service to come up
wait_for_curl () {
  local TIMEOUTS=0
  local URL=$1
  local SERVICE_NAME=$2
  echo "### URL $URL -- SERVICE $SERVICE_NAME"
  until curl -Ss -f "${URL}" || [[ ${TIMEOUTS} -eq 12 ]]; do
    echo "Waiting for ${SERVICE_NAME} to come up within 60 seconds...";
    sleep 5;
    ((TIMEOUTS+=1))
  done
  STATUS_CODE=$(curl --write-out %{http_code} --silent --output /dev/null "${URL}")
  if [[ "${STATUS_CODE}" != "200" ]]; then
    docker ps
    docker logs ${SERVICE_NAME}
    printf "\n${SERVICE_NAME} returned a %s status code" "${STATUS_CODE}. See docker logs above"
    exit 1
  fi
}

# Wait for elasticsearch
wait_for_curl "$ELASTICSEARCH_URL/_cat/health" "elasticsearch"

echo ""
echo "################################################################################"
echo "              Elasticsearch ready, waiting on Last Contact Updater"
echo "################################################################################"
echo ""

# start LCU and wait for it to come up
wait_for_curl "${UPDATER_URL}/health_check" "ems-last-contact-updater"

# Execute any analysis utilities FUTURE: None defined yet
function on_exit {
    echo "DONE!"
    trap - EXIT
}
trap on_exit EXIT


echo ""
echo "################################################################################"
echo "            Last Contact Updater ready, beginning functional testing"
echo "################################################################################"
echo ""

go test -v ./tests/functional --ginkgo.v

# Dump of elasticsearch; uncomment if needed
#curl $ELASTICSEARCH_URL/a_devicestats/_search?pretty=true